@@ -88,8 +88,12 @@ public class ReceiveTopic implements MessageListener, ExceptionListener {
     private long m_jobTopicReconnectionInterval = 30;
     private long m_runhistoryClearDelay = -1;
     
-	private boolean m_errFlg = false;
+	private volatile boolean m_errFlg = false;
 	private static boolean m_clearFlg = false;
+	
+	// heartbeat送受完了日時(jms妥当性判定用)
+	private volatile static Date heartbeatReceiveDate = new Date();
+	public static final Object _instanceHeartbeatDateLock = new Object();
 
 	/** ReceiveTopicクラス用スケジューラ * */
 	private ScheduledExecutorService m_scheduler = Executors.newScheduledThreadPool(10);
@@ -278,6 +282,11 @@ public class ReceiveTopic implements MessageListener, ExceptionListener {
             }else if(obj instanceof Dummy){
 				// TOPIC接続疎通のためのオブジェクトのため何もしない
 				log.debug("onMessage() get Dummy");
+				
+				// 最終受信日時を格納する
+				synchronized (_instanceHeartbeatDateLock) {
+					heartbeatReceiveDate = new Date();
+				}
             }else{
 				log.error("message is incorrect : " + obj.toString());
 				return;
@@ -289,6 +298,7 @@ public class ReceiveTopic implements MessageListener, ExceptionListener {
         log.debug("onMessage end");
     }
     
+	
     /* 通信エラーハンドラ
      * (non-Javadoc)
      * @see javax.jms.ExceptionListener#onException(javax.jms.JMSException)
@@ -527,7 +537,23 @@ public class ReceiveTopic implements MessageListener, ExceptionListener {
         
 	}
 	
+	/**
+	 * 接続状況を返す
+	 * @return 接続状況(再接続中 : true, 接続中　: false)
+	 */
+	synchronized public boolean isReconnecting() {
+		return m_errFlg;
+	}
 	
+	/**
+	 * Heartbeanメッセージの最終受信日時を取得するメソッド
+	 * @return Heartbeatメッセージの最終受信日時
+	 */
+	public static Date getHeartbeatReceiveDate() {
+		synchronized (_instanceHeartbeatDateLock) {
+			return heartbeatReceiveDate;
+		}
+	}
 	
 	/**
 	 * clearFlgの設定
