@@ -16,6 +16,7 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.agent;
 
 import java.util.Collection;
+import java.util.Date;
 import java.util.Iterator;
 import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;
@@ -67,7 +68,11 @@ public class UpdateRepositoryInfoReceiveTopic implements MessageListener, Except
 	
 	protected Agent m_agent;
 	
-	private boolean m_errFlg = false;
+	private volatile boolean m_errFlg = false;
+	
+	// heartbeat送受完了日時(jms妥当性判定用)
+	private volatile static Date heartbeatReceiveDate = new Date();
+	public static final Object _instanceHeartbeatDateLock = new Object();
 	
 	/** UpdateRepositoryInfoReceiveTopicクラス用スケジューラ * */
 	private ScheduledExecutorService m_scheduler = Executors.newScheduledThreadPool(10);
@@ -138,18 +143,22 @@ public class UpdateRepositoryInfoReceiveTopic implements MessageListener, Except
 					log.debug("onMessage() get Dummy : facilityId = " + dummy.getFacilityIdList().get(0));
 				else
 					log.debug("onMessage() get Dummy");
+				
+				// 最終受信日時を格納する
+				synchronized (_instanceHeartbeatDateLock) {
+					heartbeatReceiveDate = new Date();
+				}
 			}
 			else{
-				log.error("onMessage()：Invalid message type received. " + obj.getClass().getCanonicalName());
+				log.error("onMessage():Invalid message type received. " + obj.getClass().getCanonicalName());
 				return;
 			}
 		}else{
-			log.error("onMessage()：Invalid message type received. " + message.getClass());
+			log.error("onMessage():Invalid message type received. " + message.getClass());
 			return;
 		}
 	}
 	
-
 	/* 通信エラーハンドラ
 	 * (non-Javadoc)
 	 * @see javax.jms.ExceptionListener#onException(javax.jms.JMSException)
@@ -362,6 +371,24 @@ public class UpdateRepositoryInfoReceiveTopic implements MessageListener, Except
         
 	}
 	
+	/**
+	 * 接続状況を返す
+	 * @return 接続状況(再接続中 : true, 接続中　: false)
+	 */
+	synchronized public boolean isReconnecting() {
+		return m_errFlg;
+	}
+	
+	/**
+	 * Heartbeanメッセージの最終受信日時を取得するメソッド
+	 * @return Heartbeatメッセージの最終受信日時
+	 */
+	public static Date getHeartbeatReceiveDate() {
+		synchronized (_instanceHeartbeatDateLock) {
+			return heartbeatReceiveDate;
+		}
+	}
+	
 	/**
 	 * EJB再接続タイマータスク<BR>
 	 * 
